var __assign = Object.assign;

// src/injectHtml.ts
import {render} from "ejs";
function injectHtml(options = {}) {
  return {
    name: "vite:injectHtml",
    transformIndexHtml: {
      enforce: "pre",
      transform(html) {
        const {injectData = {}, injectOptions = {}, tags = []} = options;
        return {
          html: render(html, injectData, injectOptions),
          tags
        };
      }
    }
  };
}

// src/minifyHtml.ts
import {minify} from "html-minifier-terser";
function minifyHtml(minifyOptions = true) {
  return {
    name: "vite:minifyHtml",
    transformIndexHtml: {
      enforce: "post",
      transform(html) {
        if (!minifyOptions) {
          return html;
        }
        const defaultMinifyOptions = __assign({
          collapseBooleanAttributes: true,
          collapseWhitespace: true,
          minifyCSS: true,
          minifyJS: true,
          minifyURLs: true,
          removeAttributeQuotes: true,
          removeComments: true,
          removeEmptyAttributes: true
        }, typeof minifyOptions === "boolean" ? {} : minifyOptions);
        return minify(html, defaultMinifyOptions);
      }
    }
  };
}

// src/index.ts
var src_default = (options = {}) => {
  const {inject = {}, minify: minify2 = {}} = options;
  return [injectHtml(inject), minifyHtml(minify2)];
};
export {
  src_default as default,
  injectHtml,
  minifyHtml
};
